/*
 * USB-HID-Keyboard
 *
 * Meldet sich am PC als USB-Keyboard an und sendet einzelne Tastendrucke als
 * konfigurierbare Tastenkombinationen.
 *
 * Schaltung: STM32 minimal development board
 * MCU: STM32F103C8T6
 * Takt: 48MHz
 *
 * 16.09.2014 Nicolas
 */

/* Einstellungen bezueglich Tastern in "inputkeys.c" */


#include "hw_config.h"
#include "usb_lib.h"
#include "usb_pwr.h"
#include "stm32f10x_conf.h"
#include "stm32f10x_rcc.h"
#include "stm32f10x_gpio.h"
#include <stdint.h>
#include <limits.h>
#include "debughelp.h"
#include "keyboard.h"




// Globale Variablen:
__IO uint8_t PrevXferComplete = 1;
log_t log = {.cnt = 0};



/* Noch sehr grobe Implementierung zum Testen des USB-HID */
int main(void)
{
	SystemInit();
	SysTick_Config(SystemCoreClock/1000); // 1ms

    RCC_APB1PeriphClockCmd(RCC_APB1Periph_PWR, ENABLE);
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_ALLGPIO, ENABLE);




    // Schaltet viele Ausgnge als Eingang
    Set_System();

	{
		GPIO_InitTypeDef GPIO_InitStructure;
		GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
		GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
		GPIO_InitStructure.GPIO_Pin = SPARE1_Pin;
		GPIO_Init(SPARE1_GPIO, &GPIO_InitStructure);
	}


    keyboard_init();
    inputkeys_init();
    USB_Interrupts_Config();
    Set_USBClock(); // Device-unabhaengig

    USB_Init();

    while (1)
    {
    	// LED-Status-Update
    	keyboard_update();

    	// Tastenstatus abfragen
    	inputkeys_scan();

		if (bDeviceState == CONFIGURED)
		{
			// Tastenkombinationen senden
			keyboard_send();
		}
    }
}



void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */
	(void) file;
	(void) line;

    error();
}


