/*
 * Keyboard: Tastatur-spezifische Funktionen
 *  - Status LEDs aktualisieren
 *  - Keyboard-Buffer senden
 *
 * 2014-09-16 Nicolas
 */


#include <stdint.h>
#include "stm32f10x_gpio.h"
#include "stm32f10x_rcc.h"
#include "usb_lib.h"
#include "hardwareconfig.h"
#include "keyboard.h"


#define BUFFERSIZE 8

extern __IO uint8_t PrevXferComplete;
extern uint8_t Report_Buf[2];         // Input-Buffer fuer LED-Status
extern uint8_t keybuffer[BUFFERSIZE]; // Vorbereiteter HID-Output-Puffer


/* Initialisierung Keyboard-GPIO: Ausgaenge fuer Status-LEDs */
void keyboard_init(void)
{
	GPIO_InitTypeDef GPIO_InitStructure;

	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;

	GPIO_InitStructure.GPIO_Pin = KEYBOARD_LED_CAPSLOCK_Pin;
	GPIO_Init(KEYBOARD_LED_CAPSLOCK_GPIO, &GPIO_InitStructure);
	GPIO_InitStructure.GPIO_Pin = KEYBOARD_LED_NUMLOCK_Pin;
	GPIO_Init(KEYBOARD_LED_NUMLOCK_GPIO, &GPIO_InitStructure);
	GPIO_InitStructure.GPIO_Pin = KEYBOARD_LED_SCRLLOCK_Pin;
	GPIO_Init(KEYBOARD_LED_SCRLLOCK_GPIO, &GPIO_InitStructure);
}


/* Update der Status-LEDs */
void keyboard_update(void)
{

	uint8_t stat = Report_Buf[0];

	if (stat & 0x2)
		GPIO_SetBits(KEYBOARD_LED_CAPSLOCK_GPIO,KEYBOARD_LED_CAPSLOCK_Pin);
	else
		GPIO_ResetBits(KEYBOARD_LED_CAPSLOCK_GPIO,KEYBOARD_LED_CAPSLOCK_Pin);

	if (stat & 0x1)
		GPIO_SetBits(KEYBOARD_LED_NUMLOCK_GPIO,KEYBOARD_LED_NUMLOCK_Pin);
	else
		GPIO_ResetBits(KEYBOARD_LED_NUMLOCK_GPIO,KEYBOARD_LED_NUMLOCK_Pin);

	if (stat & 0x4)
	  	GPIO_SetBits(KEYBOARD_LED_SCRLLOCK_GPIO,KEYBOARD_LED_SCRLLOCK_Pin);
	else
		GPIO_ResetBits(KEYBOARD_LED_SCRLLOCK_GPIO,KEYBOARD_LED_SCRLLOCK_Pin);
}



/* Schickt den Scancode von "Strg-A" oder von "keine Taste gedrueckt" */
void keyboard_send(void)
{
	bool isnew;
	static uint8_t merker[BUFFERSIZE] = {0,0x01,0,0,0,0,0,0}; // Startwert kann
															  // nicht vorkommen

	isnew = !(memcmp(keybuffer,merker,BUFFERSIZE)==0); // achtung: const void *
	memcpy(merker,keybuffer,BUFFERSIZE);

	// Telegramme werden nur einmal gesendet
	if( !isnew ) {
		return;
	}

	/* Reset the control token to inform upper layer that a transfer is ongoing */
	PrevXferComplete = 0;

	/* Copy mouse position info in ENDP1 Tx Packet Memory Area*/
	USB_SIL_Write(EP1_IN, keybuffer, BUFFERSIZE);

	/* Enable endpoint for transmission */
	SetEPTxValid(ENDP1);
}

