/*
 * keyboard_usb_desc.c
 *
 * USB-Descriptoren fuer HID-Tastatur
 *
 * Hier werden nur globale Konstanten definiert.
 *
 * 16.09.2014 Nicolas
 */


#include "usb_lib.h"
#include "keyboard_usb_desc.h"



/* USB Standard Device Descriptor */
// Nach HID1.11-Spezifikation S. 67
const uint8_t keyboard_DeviceDescriptor[KEYBOARD_SIZ_DEVICE_DESC] =
{
    KEYBOARD_SIZ_DEVICE_DESC,   // bLength
    USB_DEVICE_DESCRIPTOR_TYPE, // bDescriptorType
    0x00,0x02,                  // bcdUSB  USB 2.0, Vielleicht spter 1.0
    0x00,                       // bDeviceClass : siehe Interface
    0x00,                       // bDeviceSubClass : siehe Interface
    0x00,                       // bDeviceProtocol : siehe Interface
    0x40,                       // bMaxPacketSize 64 <===== spaeter: 8
    0x83,0x04,                  // idVendor (0x0483)
    0x10+1,0x57,                // idProduct = 0x5711
    0x00,0x02,                  // bcdDevice rel. 2.00
    // die folgenden drei sind noch nicht angepat:
    1,                          /*Index of string descriptor describing
                                                  manufacturer */
    2,                          /*Index of string descriptor describing
                                                 product*/
    3,                          /*Index of string descriptor describing the
                                                 device serial number */
    0x01                        // number of possible configurations
};


/* USB Configuration Descriptor */
/* Alle Descriptoren (Configuration, Interface, Endpoint, Class, Vendor */
const uint8_t keyboard_ConfigDescriptor[KEYBOARD_SIZ_CONFIG_DESC] =
{
	/* Configuration Descriptor */
    // Nach HID1.11-Spezifikation S. 67
    0x09, 		// bLength: Configuration Descriptor size
    USB_CONFIGURATION_DESCRIPTOR_TYPE, // bDescriptorType: Configuration
    KEYBOARD_SIZ_CONFIG_DESC,0x00, // wTotalLength: conf+interf+endpoint+hid
    0x01,       // bNumInterfaces: 1 interface (im Dokument 2 Interfaces)
    0x01,       // bConfigurationValue: Configuration value
    0x00,       // iConfiguration: Index of string descriptor describing
                //                 the configuration
    0xD0,       // bmAttributes: Bus powered
    0x32,       // MaxPower 100 mA: this current is used for detecting Vbus

    /************** Keyboard interface Descriptor *****************************/
    // Nach HID1.11-Spezifikation S. 68
    /* 09 */
    0x09,       // bLength: Interface Descriptor size
    USB_INTERFACE_DESCRIPTOR_TYPE,/*bDescriptorType: Interface descriptor type*/
    0x00,       // bInterfaceNumber: Number of Interface
    0x00,       // bAlternateSetting: Alternate setting
    0x01,       // bNumEndpoints
    0x03,       // bInterfaceClass: HID
    0x01,       // bInterfaceSubClass : 1=BOOT, 0=no boot
    0x01,       // nInterfaceProtocol : 0=none, 1=keyboard, 2=mouse
    0x00,       // Index of string descriptor describing this interface

    /************** Keyboard HID Descriptor ***********************************/
    // Nach HID1.11-Spezifikation S. 68
    /* 18 */
    0x09,       // bLength: HID Descriptor size
    0x21,	    // bDescriptorType: HID
    0x11,0x01,	// bcdHID: HID Class Spec release number
    0x00,       // bCountryCode: Hardware target country
    0x01,       // bNumDescriptors: Number of HID class descriptors to follow
    0x22,       // bDescriptorType
    KEYBOARD_SIZ_REPORT_DESC,0x00, // wItemLength: Total length of
                                   // Report descriptor
    /************** Keyboard Endpoinr Descriptor ******************************/
    // Nach HID1.11-Spezifikation S. 68
    /* 27 */
    0x07,          // bLength: Endpoint Descriptor size
    USB_ENDPOINT_DESCRIPTOR_TYPE, /*bDescriptorType:*/
    0x80 | 0x01,   // bEndpointAddress: Endpoint Address (IN)
    0x03,          // bmAttributes: Interrupt endpoint
    0x08,0x00,     // wMaxPacketSize: 8 Byte (typisch fuer Tastaturen)
    0x20,          // bInterval: Polling Interval (10 ms)*/ spaeter 0x0A (10ms)
    /* 34 */
}; /* ConfigDescriptor */



/* Keyboard Report Descriptor gemaess Beispiel HID1.11-Spezifikation S. 69 */
const uint8_t keyboard_ReportDescriptor[KEYBOARD_SIZ_REPORT_DESC] =
{
    0x05,0x01,  // Usage Page(Generic Desktop)
    0x09,0x06,  // Usage(Keyboard)
    0xA1,0x01,  // Collection(Application)
    0x05,0x07,  // Usage Page (Key Codes)
    // 8
    0x19,0xE0,  // Usage Minimum (224)
    0x29,0xE7,  // Usage Maximum (231)
    0x15,0x00,  // Logical Minimum (0)
    0x25,0x01,  // Logical Maximum (1)
    // 16
    0x75,0x01,  // Report Size (1)
    0x95,0x08,  // Report Count (8)
    0x81,0x02,  // Input (Data, Variable, Absolute) ; modifier byte
	0x95,0x01,  // Report Count (1)
	// 24
	0x75,0x08,  // Report Size (8)
    0x81,0x01,  // Input (Constant) ; Reserved byte
    0x95,0x03,  // Report Count (3)
    0x75,0x01,  // Report Size (1)
    // 32
    0x05,0x08,  // Usage Page (Page# for LEDs)
    0x19,0x01,	// Usage Minimum (1)
    0x29,0x03,	// Usage Maximum (3)
    0x91,0x02,	// Output (Data, Variable, Absolute) ; LED report
    // 40
    0x95,0x01,  // Report Count (1)
    0x75,0x05,	// Report Size(5)
    0x91,0x01,	// Output (Constant), LED report padding
    0x95,0x06,  // Report Count (6)
    // 48
    0x75,0x08,  // Report Size (8)
    0x15,0x00,  // Logical Minumum (0)
    0x26,0xFF,0x00, // Logical Maximum (255)
    0x05,0x07,  // Usage Page (Key Codes)
    // 57
    0x19,0x00,  // Usage Minimum (0)
    0x2A,0xFF,0x00,  // Usage Maximum (255)
    0x81,0x00,  // Input (Data,Array)
    // 64
    0xC0        // End Collection
}; /* Keyboard_ReportDescriptor */


/* USB String Descriptors (optional) */
const uint8_t keyboard_StringLangID[KEYBOARD_SIZ_STRING_LANGID] =
{
    KEYBOARD_SIZ_STRING_LANGID,
    USB_STRING_DESCRIPTOR_TYPE,
    0x09,0x04 // LangID = 0x0409: U.S. English
};


const uint8_t keyboard_StringVendor[KEYBOARD_SIZ_STRING_VENDOR] =
  {
    KEYBOARD_SIZ_STRING_VENDOR, /* Size of Vendor string */
    USB_STRING_DESCRIPTOR_TYPE,  /* bDescriptorType*/
    /* Manufacturer: "STMicroelectronics" */
    'S', 0, 'T', 0, 'M', 0, 'i', 0, 'c', 0, 'r', 0, 'o', 0, 'e', 0,
    'l', 0, 'e', 0, 'c', 0, 't', 0, 'r', 0, 'o', 0, 'n', 0, 'i', 0,
    'c', 0, 's', 0
  };


const uint8_t keyboard_StringProduct[KEYBOARD_SIZ_STRING_PRODUCT] =
{
    KEYBOARD_SIZ_STRING_PRODUCT,       /* bLength */
    USB_STRING_DESCRIPTOR_TYPE,        /* bDescriptorType */
    'S', 0, 'T', 0, 'M', 0, '3', 0, '2', 0, ' ', 0, 'K', 0,
    'e', 0, 'y', 0, 'b', 0, 'o', 0, 'a', 0, 'r', 0, 'd', 0
};


uint8_t keyboard_StringSerial[KEYBOARD_SIZ_STRING_SERIAL] =
{
    KEYBOARD_SIZ_STRING_SERIAL,           /* bLength */
    USB_STRING_DESCRIPTOR_TYPE,        /* bDescriptorType */
    'S', 0, 'T', 0, 'M', 0, '3', 0, '2', 0
};


